@@ -8,4 +8,13 @@ from .authentication.verify_authentication_response import (
 )
 from .helpers import base64url_to_bytes, options_to_json
 
-__version__ = "1.7.0"
+__version__ = "1.7.2"
+
+__all__ = [
+    "generate_registration_options",
+    "verify_registration_response",
+    "generate_authentication_options",
+    "verify_authentication_response",
+    "base64url_to_bytes",
+    "options_to_json",
+]
